Index: src/shared/dartino.h |
diff --git a/src/shared/fletch.h b/src/shared/dartino.h |
similarity index 65% |
rename from src/shared/fletch.h |
rename to src/shared/dartino.h |
index d0d21ec0f629d810911916a5a6bd548665d6b569..760578dd5755b1b27540d5c817e252318000bf58 100644 |
--- a/src/shared/fletch.h |
+++ b/src/shared/dartino.h |
@@ -2,19 +2,19 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-#ifndef SRC_SHARED_FLETCH_H_ |
-#define SRC_SHARED_FLETCH_H_ |
+#ifndef SRC_SHARED_DARTINO_H_ |
+#define SRC_SHARED_DARTINO_H_ |
#include "src/shared/globals.h" |
-namespace fletch { |
+namespace dartino { |
-// Fletch is a helper class used to call system wide functions such as |
+// Dartino is a helper class used to call system wide functions such as |
// initialization. The definition of the class is shared between the |
// compiler and the VM, but both of these have their own implementation. |
-class Fletch { |
+class Dartino { |
public: |
// Initialize Fletch and all its subsystems. |
static void Setup(); |
static void TearDown(); |
@@ -23,9 +23,9 @@ class Fletch { |
// Make sure that this class can not ever be instantiated. All its methods |
// should be static class methods. |
DISALLOW_ALLOCATION(); |
- DISALLOW_IMPLICIT_CONSTRUCTORS(Fletch); |
+ DISALLOW_IMPLICIT_CONSTRUCTORS(Dartino); |
}; |
-} // namespace fletch |
+} // namespace dartino |
-#endif // SRC_SHARED_FLETCH_H_ |
+#endif // SRC_SHARED_DARTINO_H_ |
@@ -2,19 +2,19 @@ |
public: |
- // Initialize Fletch and all its subsystems. |
+ // Initialize Dartino and all its subsystems. |
static void Setup(); |
static void TearDown(); |